Crate lance_index_core

Crate lance_index_core 

Modules

metrics
scalar
Abstract scalar index traits and types for Lance index plugins

Enums

IndexType
Index Type

Traits

Index
Generic methods common across all types of secondary indices
IndexParams